pub struct QueuePairEndpoint {
pub num: u32,
pub lid: u16,
}Expand description
The addressing information required to connect to a specific Queue Pair.
This struct contains the Local Identifier (LID) and Queue Pair Number (QPN). You must send this information to the remote peer so they can connect their QP to this one.
Fields
num: u32Queue Pair Number (QPN) — the 24-bit hardware identifier for this queue pair.
lid: u16Local Identifier (LID) — the 16-bit subnet address of the port this QP is on.