ReceiveWorkRequest

Struct ReceiveWorkRequest 

pub struct ReceiveWorkRequest<'wr, 'data> { /* private fields */ }
A request to receive data from a remote peer.

In a Receive operation, the local node provides a buffer to store incoming data sent by a remote node. This request must be posted before the incoming message arrives.

Lifetimes

  • 'wr — The lifetime of this struct. It must live until the request is posted to the Queue Pair.
  • 'data — The lifetime of the local data buffer. It is tied to the ScatterElement and must remain valid until the operation completes.

Implementations

Source

impl<'wr, 'data> ReceiveWorkRequest<'wr, 'data>

pub fn new(scatter_elements: &'wr mut [ScatterElement<'data>]) -> Self

Creates a new Receive request using the provided list of scatter elements.

pub fn only_immediate() -> Self

Creates a new Receive request with an empty buffer, for receiving only immediate data.