pub struct SendWorkRequest<'wr, 'data> { /* private fields */ }Expand description
A request to send data to a remote peer.
In a Send operation, the local node pushes data to a remote node. The remote node must
have posted a corresponding ReceiveWorkRequest to accept the data.
Lifetimes
'wr— The lifetime of this struct. It must live until the request is posted to the Queue Pair.'data— The lifetime of the local data buffer. It is tied to theGatherElementand must remain valid until the operation completes.
Implementations
Sourceimpl<'wr, 'data> SendWorkRequest<'wr, 'data>
impl<'wr, 'data> SendWorkRequest<'wr, 'data>
Sourcepub fn new(gather_elements: &'wr [GatherElement<'data>]) -> Self
pub fn new(gather_elements: &'wr [GatherElement<'data>]) -> Self
Creates a new Send request using the provided list of gather elements.
Sourcepub fn with_immediate(self, imm_data: u32) -> Self
pub fn with_immediate(self, imm_data: u32) -> Self
Attach immediate data (a 32-bit integer) to the operation.
Sourcepub fn only_immediate(imm_data: u32) -> Self
pub fn only_immediate(imm_data: u32) -> Self
Creates a new Send request containing only immediate data (0-byte payload).