pub struct WorkError { /* private fields */ }Expand description
Represents a failed Work Request.
This error is returned when polling the Completion Queue results in a status other than IBV_WC_SUCCESS.
It encapsulates the standard ibverbs status code as well as vendor-specific diagnostic information.
Implementations
Sourceimpl WorkError
impl WorkError
Sourcepub fn raw_status(&self) -> u32
pub fn raw_status(&self) -> u32
Returns the raw ibv_wc.status value returned by the hardware.
Sourcepub fn vendor_code(&self) -> u32
pub fn vendor_code(&self) -> u32
Returns the vendor-specific error syndrome.
This value is hardware-dependent (e.g., Mellanox/NVIDIA ConnectX syndrome). It can be used to look up deep hardware diagnostics in the vendor’s programmer manual.
Sourcepub fn code(&self) -> WorkErrorCode
pub fn code(&self) -> WorkErrorCode
Returns the canonical error code enum.