PreparedBarrier

Enum PreparedBarrier 

pub enum PreparedBarrier {
    Centralized(PreparedLinearBarrier),
    BinaryTree(PreparedBinaryTreeBarrier),
    Dissemination(PreparedDisseminationBarrier),
}
A barrier that has been allocated but not yet linked to remote peers.

Call link_remote with the remote memory region handles after the endpoint exchange to produce a Barrier.

Variants



Centralized(PreparedLinearBarrier)

Leader-based barrier. See BarrierAlgorithm::Centralized.



BinaryTree(PreparedBinaryTreeBarrier)

Binary-tree barrier. See BarrierAlgorithm::BinaryTree.



Dissemination(PreparedDisseminationBarrier)

Dissemination barrier. See BarrierAlgorithm::Dissemination.

Implementations

Source

impl PreparedBarrier

pub fn remote_mr(&self) -> PeerRemoteMemoryRegion

Returns this node’s barrier memory region handle for exchange with peers.

Links remote peer memory regions and returns a ready-to-use Barrier.