pub struct NetworkChannelEndpoint { /* private fields */ }Expand description
The per-peer endpoint information exchanged during setup, containing both the queue pair endpoint and the barrier memory region handle.