pub struct PreparedChannel { /* private fields */ }Expand description
A Channel that has been configured but not yet connected to a remote peer.
Created by Channel::builder. Call endpoint to obtain the
local connection information, exchange it with the remote side, then call
handshake with the remote’s endpoint to finish the connection.
Implementations
Sourceimpl PreparedChannel
impl PreparedChannel
Sourcepub fn endpoint(&self) -> QueuePairEndpoint
pub fn endpoint(&self) -> QueuePairEndpoint
Returns the local endpoint information needed by the remote peer to complete the handshake.