pub struct DeviceList { /* private fields */ }Expand description
Owned list of available ibverbs RDMA devices.
This type wraps the device list returned by ibv_get_device_list.
The underlying resources are released automatically when the value
is dropped.
Individual devices can be accessed via iteration or indexing using
DeviceList::iter or DeviceList::get.
Implementations
Sourceimpl DeviceList
impl DeviceList
Sourcepub fn iter(&self) -> DeviceListIter<'_> ⓘ
pub fn iter(&self) -> DeviceListIter<'_> ⓘ
Returns an iterator over all available devices.