pub struct PreparedMultiChannel { /* private fields */ }Expand description
A MultiChannel that has been configured but not yet connected to a remote peer.
Created by MultiChannel::builder. Call endpoints to obtain the
local connection information for each channel, exchange them with the remote side, then
call handshake with the remote’s endpoints to finish the connections.
Implementations
Sourceimpl PreparedMultiChannel
impl PreparedMultiChannel
Sourcepub fn endpoints(&self) -> Box<[QueuePairEndpoint]>
pub fn endpoints(&self) -> Box<[QueuePairEndpoint]>
Returns the local endpoint information for each channel, needed by the remote peer.
Sourcepub fn handshake<I>(self, endpoints: I) -> IbvResult<MultiChannel>
pub fn handshake<I>(self, endpoints: I) -> IbvResult<MultiChannel>
Connects each channel to the remote endpoint at the same index and returns a ready-to-use MultiChannel.