pub struct Exchanger {}Expand description
TCP-based all-to-all data exchange between nodes in a network.
Used during setup to exchange RDMA endpoint information (e.g. QueuePairEndpoint)
between peers over TCP before RDMA channels are established.
Implementations
Sourceimpl Exchanger
impl Exchanger
Sourcepub fn await_exchange_all<T: Serialize + DeserializeOwned + Clone>(
rank: usize,
network: &NetworkConfig,
data: &T,
config: &ExchangeConfig,
) -> Result<Vec<T>, ExchangeError>
pub fn await_exchange_all<T: Serialize + DeserializeOwned + Clone>( rank: usize, network: &NetworkConfig, data: &T, config: &ExchangeConfig, ) -> Result<Vec<T>, ExchangeError>
Exchanges data with all other nodes in the network, blocking until complete or timeout.
Returns a Vec<T> indexed by rank, where the entry at this node’s rank is a clone
of the local data and all other entries come from the corresponding remote nodes.